package org.example;

import com.itextpdf.text.*;
import com.itextpdf.text.pdf.PdfWriter;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.lang.reflect.Array;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.UUID;

public class Car {
    private String model;
    public String color;
    public int id;
    public UUID uuid;
    private int year;
    public Airbag[] airbags;
    public boolean hasInvoice = false;
    public String photoSrc = "";
    public CustomDate purchaseDate;
    public float price;
    public float vat;
    private ArrayList<String> gallery = new ArrayList<>();

    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
        this.hasInvoice = false;
        assignPhoto();
    }

    public int getYear() {
        return year;
    }

    public void setYear(int year) {
        this.year = year;
        this.hasInvoice = false;
    }

    public void assignPhoto() {
        String filePath = "photos/" + this.model + ".jpg";
        File f = new File(filePath);
        if(!f.exists() || f.isDirectory()) {
            this.photoSrc = "";
            return;
        }

        this.photoSrc = filePath;
    }

    public Car(String model, String color, int year, Airbag[] airbags, CustomDate purchaseDate, float price, float vat) {
        this.model = model;
        this.color = color;
        this.year = year;
        this.airbags = airbags;
        this.uuid = UUID.randomUUID();
        this.purchaseDate = purchaseDate;
        this.price = price;
        this.vat = vat;

        assignPhoto();
    }

    public void generateInvoice() {
        Document document = new Document();
        String path = "invoices/" + this.uuid.toString() + ".pdf";
        try {
            PdfWriter.getInstance(document, new FileOutputStream(path));
        } catch (DocumentException | FileNotFoundException e) {
            throw new RuntimeException(e);
        }

        String airbagsString = "";
        for (Airbag airbag : this.airbags) {
            airbagsString += "Poduszka powietrzna " + airbag.description + ": " + (airbag.value ? "TAK" : "NIE") + "\n";
        }

        DateTimeFormatter dtf = DateTimeFormatter.ofPattern("dd.MM.yyyy HH:mm:ss");
        LocalDateTime now = LocalDateTime.now();

        document.open();
        Font headerFont = FontFactory.getFont("Roboto Black", 20, BaseColor.BLACK);
        Font contentFont = FontFactory.getFont("Roboto", 12, BaseColor.BLACK);

        Paragraph header = new Paragraph("Faktura dla " + this.uuid, headerFont);
        Paragraph model = new Paragraph("Model: " + this.model, contentFont);
        Paragraph info = new Paragraph(
                "Kolor: " + this.color +
                "\nRok produkcji: " + this.year +
                "\n" + airbagsString +
                "\nWygenerowano: " + dtf.format(now) + "\n\n", contentFont);

        try {
            document.add(header);
            document.add(model);
            document.add(info);
        } catch (DocumentException e) {
            throw new RuntimeException(e);
        }

        try {
            Image img = Image.getInstance(this.photoSrc);
            img.scaleToFit(300, 300);
            img.setAlignment(Element.ALIGN_CENTER);
            document.add(img);
        } catch (Exception e) {

        }

        document.close();
        this.hasInvoice = true;
    }

    public void addGalleryPhotos(String[] filePaths) {
        if(this.gallery == null) this.gallery = new ArrayList<>();
        Collections.addAll(this.gallery, filePaths);
    }

    public String[] getGalleryPhotos() {
        return this.gallery.toArray(new String[0]);
    }
}
