const contentDiv = document.getElementById('content');
const editDialog = document.getElementById('editDialog');
let data;

async function loadData() {
    data = await fetchAPI('json', null, 'GET');
    createTable();
}

function createTable() {
    let html = `<table class="carsTable"><thead><tr>
        <th>Index</th>
        <th>UUID</th>
        <th>Model</th>
        <th>Rok</th>
        <th>Data zakupu</th>
        <th>Cena</th>
        <th>Kolor</th>
        <th>Poduszki powietrzne</th>
        <th>Zdjęcie</th>
        <th>Faktura</th>
        <th>Edycja</th>
        <th>Galeria</th>
    </tr></thead><tbody>`;

    for (let i = 0; i < data.length; i++) {
        let car = data[i];
        let invoiceState = car.hasInvoice ? '' : 'disabled';
        html += `<tr>
            <td>${car.id}</td>
            <td>${car.uuid}</td>
            <td>${car.model}</td>
            <td>${car.year}</td>
            <td>${processDate(car.purchaseDate)}</td>
            <td>${processPrice(car.price, car.vat)}</td>
            <td>${processColor(car.color)}</td>
            <td>${processAirbags(car.airbags)}</td>
            <td>${processPhoto(car)}</td>
            <td>
                <div class="actionsCell">
                    <button onclick="addInvoice('${car.uuid}')">Utwórz fakturę</button>
                    <button onclick="downloadInvoice('${car.uuid}')" ${invoiceState}>Pobierz fakturę</button>
                </div>
            </td>
            <td>
                <div class="actionsCell">
                    <button onclick="editCar('${i}')">Edytuj</button>
                    <button onclick="deleteCar('${car.uuid}')">Usuń</button>
                </div>
            </td>
            <td>
                <div class="actionsCell">
                    <button onclick="goToPage('/gallery.html?uuid=${car.uuid}')">Pokaż galerię</button>
                </div>
            </td>
        </tr>`;
    }

    html += '</tbody></table>';
    contentDiv.innerHTML = html;
}

function processDate(date) {
    if(!date) return '?';
    return `${date.day}.${date.month}.${date.year}`;
}

function processPrice(price, vat) {
    return `${parseInt(price)} PLN<br>+${vat}% VAT`;
}

function processColor(color) {
    return `<div class="carColor" style="background-color: ${color}">${color}</div>`
}

function processPhoto(car) {
    if(!car.photoSrc) return 'Brak zdjęcia';
    return `<img class="carPhoto" src="/${car.photoSrc}" alt="Car photo">`
}

function processAirbags(airbags) {
    let html = '';
    for (let i = 0; i < airbags.length; i++) {
        let airbag = airbags[i];
        html += `<input type="checkbox" id="carAirbag${airbag.description}" onclick="return false;" ${airbag.value ? 'checked' : ''}>
        <label for="carAirbag${airbag.description}">${airbag.description}</label><br>`;
    }

    return html;
}

function editCar(index) {
    const car = data[index];
    let html = `<form id="editCarForm" onsubmit="return false;">
        <table class="fixedSize margin8">
            <tr>
                <td><label for="carModel">Model</label></td>
                <td><input type="text" id="carModel" value="${car.model}"></td>
            </tr>
            <tr>
                <td><label for="carYear">Rok</label></td>
                <td><input type="number" id="carYear" value="${car.year}"></td>
            </tr>
        </table>
        <input type="submit" value="Zapisz">
    </form>`;

    editDialog.innerHTML = html;
    editDialog.showModal();

    const editCarForm = document.getElementById('editCarForm');
    editCarForm.addEventListener('submit', async (e) => {
        editDialog.close();
        const data = {
            uuid: car.uuid,
            model: editCarForm.carModel.value,
            year: editCarForm.carYear.value
        }

        await fetchAPI('update', data, 'POST');
        loadData();
    });
}

async function deleteCar(uuid) {
    await fetchAPI('delete', {uuid: uuid}, 'POST');
    loadData();
}

async function addInvoice(uuid) {
    await fetchAPI('invoice', {uuid: uuid}, 'POST');
    loadData();
}

loadData();