const imageToEdit = document.getElementById('imageToEdit');
const filename = window.location.search.split('name=')[1].split('&')[0];
const url = '/galleryPhotos/' + filename;
const editButtons = document.getElementById('editButtons');
const img = new Image();

let cropMode = 0;
let cropStart, cropEnd;

async function drawImage() {
    img.onload = () => {
        updateCanvas();
    }
    img.src = url + '?t=' + Date.now();
}

function updateCanvas() {
    imageToEdit.width = img.width;
    imageToEdit.height = img.height;
    
    const ctx = imageToEdit.getContext('2d');
    ctx.drawImage(img, 0, 0, imageToEdit.width, imageToEdit.height);

    if(cropStart && cropEnd) {
        ctx.strokeStyle = 'red';
        ctx.lineWidth = 2;
        ctx.strokeRect(
            ...getCropRect(false)
        );
    }
}

imageToEdit.addEventListener('mousedown', (e) => {
    const pos = getMousePos(e);

    switch(cropMode) {
        case 0:
            cropStart = pos;
            break;
        case 1:
            cropEnd = pos;
            break;
    }
    cropMode++;
    if(cropMode > 2) {
        resetCrop();
    }
    updateCanvas();
});

imageToEdit.addEventListener('mousemove', (e) => {
    const pos = getMousePos(e);

    if(cropMode == 1) {
        cropEnd = pos;
        updateCanvas();
    }
});

function getCropRect(realSize) {
    const coefX = realSize ? imageToEdit.width / img.width : 1;
    const coefY = realSize ? imageToEdit.height / img.height : 1;
    return [
        Math.min(cropStart.x, cropEnd.x) * coefX,
        Math.min(cropStart.y, cropEnd.y) * coefY,
        Math.abs(cropEnd.x - cropStart.x) * coefX, 
        Math.abs(cropEnd.y - cropStart.y) * coefY
    ];
}

function getMousePos(e) {
    const rect = imageToEdit.getBoundingClientRect();
    return {
        x: (e.clientX - rect.left),
        y: (e.clientY - rect.top)
    };
}

editButtons.addEventListener('submit', (e) => {
    e.preventDefault();
    const effect = e.submitter.value;

    if(effect == 'crop') return doCropping();

    applyEfect(effect);
});

async function applyEfect(effect, params) {
    const obj = {
        filename: filename,
        effect: effect,
        params: params || []
    }

    console.log(obj);
    await fetchAPI('galleryEdit', obj, 'POST');
    drawImage();
}

function resetCrop() {
    cropMode = 0;
    cropStart = null;
    cropEnd = null;
}

function doCropping() {
    if(!cropStart || !cropEnd) return;
    applyEfect('crop', getCropRect(true));
    resetCrop();
}

drawImage();